import io
import os

from setuptools import find_packages, setup

HERE = os.path.abspath(os.path.dirname(__file__))


def load_readme():
    with io.open(os.path.join(HERE, "README.rst"), "rt", encoding="utf8") as f:
        return f.read()


def load_about():
    about = {}
    with io.open(
        os.path.join(HERE, "tutor_social_auth_michiganonline", "__about__.py"),
        "rt",
        encoding="utf-8",
    ) as f:
        exec(f.read(), about)  # pylint: disable=exec-used
    return about


ABOUT = load_about()


setup(
    name="tutor-contrib-social-auth-michiganonline",
    version=ABOUT["__version__"],
    url="https://github.com/academic-innovation/tutor-contrib-social-auth-michiganonline",
    project_urls={
        "Code": "https://github.com/academic-innovation/tutor-contrib-social-auth-michiganonline",
        "Issue tracker": "https://github.com/academic-innovation/tutor-contrib-social-auth-michiganonline/issues",
    },
    license="Apache 2.0",
    author="Dennis O’Reilly",
    author_email="doreilly@umich.edu",
    description="social-auth-michiganonline plugin for Tutor",
    long_description=load_readme(),
    long_description_content_type="text/x-rst",
    packages=find_packages(exclude=["tests*"]),
    include_package_data=True,
    python_requires=">=3.8",
    install_requires=["tutor>=16.0.0,<19.0.0","importlib-resources>=1.3"],
    extras_require={
        "dev": [
            "tutor[dev]>=16.0.0,<19.0.0",
        ]
    },
    entry_points={
        "tutor.plugin.v1": [
            "social-auth-michiganonline = tutor_social_auth_michiganonline.plugin"
        ]
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
)
